import 'dart:async';
import 'dart:io';

import 'package:process_run/shell.dart';

void main() async {
  await Future.doWhile(() async {
    stdout.write('.');

    final hasSound = await checkForSound(timeFrame: 10);

    if (!hasSound) await Future.delayed(Duration(seconds: 15));

    return hasSound;
  });

  stdout.write('\n');

  print('no sound, so shutdown');
}

Future<bool> checkForSound(
    {int timeFrame = 30, double thresholdDb = -49.0}) async {
  final stdErr = StreamController<List<int>>();

  final List<String> errorOutput = [];

  final shell = Shell(stderr: stdErr, verbose: false);

  stdErr.stream.listen((outputChars) =>
      errorOutput.addAll(String.fromCharCodes(outputChars).split('\n')));

  await shell.run(
      '/usr/local/bin/ffmpeg -nostdin -y -t $timeFrame -f avfoundation -i ":2" -af "volumedetect" -f null /dev/null');

  final String volumeLine = errorOutput.singleWhere(
      (outputLine) => RegExp(r'^.* mean_volume: .*dB$').hasMatch(outputLine));

  final String volume = volumeLine.replaceAllMapped(
      RegExp(r'.*mean_volume: (-?\d+\.\d+).*'), (match) => '${match.group(1)}');

  return double.parse(volume) > thresholdDb;
}

//ffmpeg -nostats -loglevel info -f avfoundation -i ":2" -af silencedetect=n=-49dB:d=30 -f null - 2>&1
